#
# spec file for package mate-user-guide
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.28

Name:           mate-user-guide
Version:        1.28.0
Release:        1.1
Summary:        User guide for the MATE desktop
License:        GFDL-1.1-or-later
Group:          Documentation/HTML
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(glib-2.0)
Requires:       yelp
Recommends:     %{name}-lang
BuildArch:      noarch

%description
This package contains documentation targeted for end-users of
MATE Desktop Environment with general MATE applicability.

%lang_package

%prep
%setup -q

%build
NOCONFIGURE=1 mate-autogen
%configure
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc AUTHORS NEWS README
%{_datadir}/applications/%{name}.desktop
%doc %{_datadir}/help/C/%{name}/

%files lang -f %{name}.lang

%changelog
* Tue Mar 26 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.28.0
  * Update translations
* Fri Nov 17 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.2
  * update translations
  * fix warnings in de, es, fr, id, it, ja, ko, pl, sl, sr and sv translations
* Mon May 15 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.26.1:
  * goscustdesk: Fix typos.
  * goscaja: Fix typos.
  * Update translations.
* Thu Aug 12 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Update translations
  * pre-bump version
  * build: allow users to disable gettext support (--disable-nls)
  * Update copyright to 2021
  * Remove the execution bit from some Italian figures
  * Remove USE_MATE2_MACROS from autogen.sh (legacy)
  * Update README
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0:
  * Change language to refer to Classic Menu and Compact Menu.
  * Sets the required version for gettext (0.19.8).
  * Migrate from intltool to gettext.
  * Update transaltions.
- Drop support for old openSUSE versions.
* Thu Jul 18 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.1 (changes since 1.22.1):
  * remove live.gnome & update joining MATE section
  * update reporting-bugs section
  * remove custom-command-options section and correct syntax
  * update preferred applications section
  * update reporting-bugs section
  * gosoverview.xml: Reduce link attributes
  * Update transaltions.
* Sun May 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.22.1:
  * Replace docbook link with xref and fix a linkend attribute.
  * help: Update copyright.
  * Upgrade the manual to docbook 5.0.
  * Update translations.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Add autogen.sh to Extra_dist.
  * Replace -Dokumentationsprojekt with Documentation Project.
  * Virtual filesystem in Unix-like operating systems.
  * Update translations.
* Sun Nov 25 2018 sor.alexei@meowr.ru
- Update to version 1.20.2:
  * Use make functions for HELP_LINGUAS.
  * Update instructions for editing keyboard shortcuts.
  * Add keyboard shortcut for showing hidden files.
  * Systems without dconf profiles.
  * dconf settings storage system.
  * Remove extra char.
  * GNOME Media is deprecated: Remove gstreamer-properties.
  * Remove full stop (period) in title ending.
  * Remove menu_panel.png.
  * Show MATE logo in menu panel.
  * Fix installation.
  * Resize screenshot.
  * Browser mode is the default in MATE.
  * Fix figure title - search bar.
  * Add autogen.sh to Extra_dist.
  * Update translations.
* Fri Jun 22 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * Update translations of content.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Sync translations of desktop file with Transifex.
  * Add Changelog generation.
* Wed Jan 27 2016 sor.alexei@meowr.ru
- Update to version 1.13.0.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
* Thu Oct  8 2015 sor.alexei@meowr.ru
- Update to 1.11.0.
- Add mate-user-guide-lang package.
* Fri Jun 12 2015 sor.alexei@meowr.ru
- Initial package.
